# AI Pattern Analysis: test_executor.py

**Generated:** 2026-01-18 02:30:54
**Date:** 2026-01-18
**Time:** 02:30:54

---

Found 12 potential issues:

- 🔴 HIGH: 3
- 🟡 MEDIUM: 0
- 🟢 LOW: 9

| Severity | Line | Pattern | Message | Suggestion |
|----------|------|---------|---------|------------|
| 🔴 HIGH | 71 | `copy_paste_blocks` | Potential copy-paste from line 43 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 206 | `copy_paste_blocks` | Potential copy-paste from line 201 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 445 | `copy_paste_blocks` | Potential copy-paste from line 421 | Extract duplicated logic into a reusable function. |
| 🟢 LOW | 199 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 203 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 208 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 214 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 216 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 220 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 224 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 353 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 453 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
